import os
os.environ['PATH'] = 'C:/nep/opencv_cuda' + os.pathsep + os.environ['PATH']
import cv2
import numpy as np
import math


class MediapipeFace():

    def __init__(self, model_selection=1, min_detection_confidence=0.5):
        import mediapipe as mp
        self.mp_drawing = mp.solutions.drawing_utils
        self.mp_drawing_styles = mp.solutions.drawing_styles
        self.mp_face_detection = mp.solutions.face_detection

        self.face_detection = self.mp_face_detection.FaceDetection(model_selection=model_selection, min_detection_confidence=min_detection_confidence)


    def _normalized_to_pixel_coordinates(self, normalized_x, normalized_y, image_width,image_height):

        x_px = min(math.floor(normalized_x * image_width), image_width - 1)
        y_px = min(math.floor(normalized_y * image_height), image_height - 1)
        
        return x_px, y_px

    def drawFace(self, image_src):

        if len(self.faces) == 0:
            return image_src            
        else:
            new_image = image_src.copy()
            for detection in self.face_results.detections:
                self.mp_drawing.draw_detection(new_image, detection)
            return new_image

    def getFace(self, image_src):

            image_src.flags.writeable = False
            image_src = cv2.cvtColor(image_src, cv2.COLOR_BGR2RGB)
            self.face_results = self.face_detection.process(image_src)
            y_resolution, x_resolution, c = image_src.shape
            image_src.flags.writeable = True

            self.faces = {}
            if self.face_results.detections:
                for detection in self.face_results.detections:
                    data = detection.location_data
                    xmin = data.relative_bounding_box.xmin
                    ymin = data.relative_bounding_box.ymin
                    width = data.relative_bounding_box.width
                    height= data.relative_bounding_box.height
                    xmin, ymin = self._normalized_to_pixel_coordinates(xmin, ymin, x_resolution,y_resolution)
                    width, height = self._normalized_to_pixel_coordinates(width, height, x_resolution,y_resolution)

                    self.faces= {detection.label_id[0]:{"xmin":xmin, "ymin":ymin, "width":width, "height":height}}

                    #print(detection.label_id[0])
                    #print(data.relative_bounding_box.xmin)

                return self.faces


import cv2
import numpy as np
import math

class MediapipeBody():

    def __init__(self, min_detection_confidence=0.5, min_tracking_confidence=0.5):
        import mediapipe as mp
        self.mp_pose = mp.solutions.pose
        self.pose = self.mp_pose.Pose(min_detection_confidence=min_detection_confidence, min_tracking_confidence=min_tracking_confidence)
        self.skeleton_detection = self.mp_pose.Pose(static_image_mode=True,model_complexity=2,enable_segmentation=True,min_detection_confidence=0.5)
        self.mp_drawing = mp.solutions.drawing_utils
        self.mp_drawing_styles = mp.solutions.drawing_styles


    def drawBody(self, image_src):
        new_image = image_src.copy()
        self.mp_drawing.draw_landmarks(
            new_image,
            self.hand_results.pose_landmarks,
            self.mp_pose.POSE_CONNECTIONS,
            landmark_drawing_spec=self.mp_drawing_styles.get_default_pose_landmarks_style())


        return new_image
    
  
    def getBody(self, image_src):
        image_src.flags.writeable = False
        image_src = cv2.cvtColor(image_src, cv2.COLOR_BGR2RGB)
        self.hand_results = self.skeleton_detection.process(image_src)
        y_resolution, x_resolution, c = image_src.shape

        # Draw the pose annotation on the image.
        image_src.flags.writeable = True
        image_src = cv2.cvtColor(image_src, cv2.COLOR_RGB2BGR)

        list_pose = ["NOSE",
            "LEFT_EYE_INNER",
            "LEFT_EYE",
            "LEFT_EYE_OUTER",
            "RIGHT_EYE_INNER",
            "RIGHT_EYE",
            "RIGHT_EYE_OUTER",
            "LEFT_EAR",
            "RIGHT_EAR",
            "MOUTH_LEFT",
            "MOUTH_RIGHT",
            "LEFT_SHOULDER",
            "RIGHT_SHOULDER",
            "LEFT_ELBOW",
            "RIGHT_ELBOW",
            "LEFT_WRIST",
            "RIGHT_WRIST",
            "LEFT_PINKY",
            "RIGHT_PINKY",
            "LEFT_INDEX",
            "RIGHT_INDEX",
            "LEFT_THUMB",
            "RIGHT_THUMB",
            "LEFT_HIP",
            "RIGHT_HIP",
            "LEFT_KNEE",
            "RIGHT_KNEE",
            "LEFT_ANKLE",
            "RIGHT_ANKLE",
            "LEFT_HEEL",
            "RIGHT_HEEL",
            "LEFT_FOOT_INDEX",
            "RIGHT_FOOT_INDEX"]

        init_value = {"x":0,"y":0, "p":0}
        pose_values = {};

        for element in list_pose:
            pose_values[element] = init_value
            #print(element)
            try:
                value = self.hands_results.pose_landmarks.landmark[self.mp_pose.PoseLandmark[element]]
                value.x, value.y = self._normalized_to_pixel_coordinates(value.x, value.y, x_resolution,y_resolution)
                pose_values[element] = {"x":value.x,"y":value.y, "p":1}
            except:
                pass
    
        return pose_values

    def _normalized_to_pixel_coordinates(self, normalized_x, normalized_y, image_width,image_height):

      x_px = min(math.floor(normalized_x * image_width), image_width - 1)
      y_px = min(math.floor(normalized_y * image_height), image_height - 1)
      
      return x_px, y_px


import os
os.environ['PATH'] = 'C:/nep/opencv_cuda' + os.pathsep + os.environ['PATH']
import cv2
import numpy as np

class SSD():
    import numpy as np
    import time

    def __init__(self, classes, path_deep_model, config = {"inpWidth":320,"inpHeight":320,"confThreshold":0.5}, fix_index = False):
        self.classes = classes
        self.config = config
        self.fix_index = fix_index
        self.confThreshold = config["confThreshold"]

        print("[INFO] Loading model...")

        self.net = cv2.dnn.readNetFromCaffe(path_deep_model + "/model.prototxt",  path_deep_model +  "/model.caffemodel")
        self.net.setPreferableTarget(cv2.dnn.DNN_TARGET_CPU)
        print("[INFO] Model ready...")

    def getObjects(self,img):
        # Runs the detection on a frame and return bounding boxes and predicted labels
        detections = self.predict_detection(img, self.net)
        self.detected = self.proccess_prediction(img, detections, self.confThreshold)
        return self.detected

    def drawObjects(self, img_src):

        new_image = img_src.copy()

        for value in self.detected: 
            startX = value["box"]["x"] 
            startY = value["box"]["y"] 
            endX = startX + value["box"]["w"] 
            endY = startY + value["box"]["h"]
            cv2.rectangle(new_image, (startX, startY), (endX, endY),(255, 0, 0), 2)
            labelPosition = endY - 5
            cv2.putText(new_image, value["label"], (startX, labelPosition),
                    cv2.FONT_HERSHEY_DUPLEX, 0.4, (255, 255, 255), 1)

        # Put efficiency information. The function getPerfProfile returns the 
        # overall time for inference(t) and the timings for each of the layers(in layersTimes)
        t, _ = self.net.getPerfProfile()
        label = 'Inference time: %.2f ms' % (t * 1000.0 / cv2.getTickFrequency())
        cv2.putText(new_image, label, (0, 15), cv2.FONT_HERSHEY_SIMPLEX, 0.5, (0, 0, 255))
        return new_image



    def predict_detection(self,frame, net):
        '''
        Predict the objects present on the frame
        '''
        # Conversion to blob
        blob = cv2.dnn.blobFromImage(cv2.resize(frame, (300, 300)),0.007843, (300, 300), 127.5)
        #blob = cv2.dnn.blobFromImage(cv2.resize(frame, (300, 300)),0.007843, (300, 300), (127.5, 127.5, 127.5), False)
        # Detection and prediction with model
        self.net.setInput(blob)
        return self.net.forward()


    def proccess_prediction(self, frame, detections, threshold):
        '''
        Filters the predictions with a confidence threshold and draws these predictions
        '''

        detected = []
        (height, width) = frame.shape[:2]
        for i in np.arange(0, detections.shape[2]):
            confidence = detections[0, 0, i, 2]
        
            if confidence > threshold:
                # Index of class label and bounding box are extracted
                idx = int(detections[0, 0, i, 1])
                box = detections[0, 0, i, 3:7] * np.array([width, height, width, height])

                # Retreives corners of the bounding box
                (startX, startY, endX, endY) = box.astype("int")
                label_ = "{}: {:.2f}%".format(self.classes[idx], confidence*100)
                label = self.classes[idx]
                position = [(startX + endX)/2, (startY + endY)/2]
                w = endX - startX
                h = endY - startY

                detected.append({"label":label, "center":{"x":int(position[0]), "y":int(position[1])},  "box":{"x":int(startX), "y":int(startY), "w":int(w), "h":int(h)}, "confidence":float(confidence)})

        return detected


class YOLO():

    import numpy as np
    import time


    def __init__(self, classes, path_deep_model, config = {"inpWidth":320,"inpHeight":320,"confThreshold":0.5, "nmsThreshold":0.5},  use_gpu = False, fix_index = False):
        self.classes = classes
        self.config = config
        self.fix_index = fix_index
        self.confThreshold = config["confThreshold"]
        self.nmsThreshold =  config["nmsThreshold"]

        print("[INFO] Loading model...")

        modelConfiguration = path_deep_model + "/model.cfg";
        modelWeights = path_deep_model + "/model.weights";

        self.net = cv2.dnn.readNetFromDarknet(modelConfiguration, modelWeights)
        if use_gpu:
            self.net.setPreferableBackend(cv2.dnn.DNN_BACKEND_CUDA)
            self.net.setPreferableTarget(cv2.dnn.DNN_TARGET_CUDA_FP16)
            print("[INFO] Using GPU...")
        else:
            self.net.setPreferableBackend(cv2.dnn.DNN_BACKEND_OPENCV)
            self.net.setPreferableTarget(cv2.dnn.DNN_TARGET_CPU) # DNN_TARGET_OPENCL_FP16,DNN_TARGET_OPENCL,DNN_TARGET_CPU = 0
            print("[INFO] Using CPU...")

        print("[INFO] DL model ready...")


    def _getOutputsNames(self, net):
        # Get the names of all the layers in the network
        layersNames = net.getLayerNames()
        if(self.fix_index == True):
            # Get the names of the output layers, i.e. the layers with unconnected outputs
            return [layersNames[i[0] - 1] for i in net.getUnconnectedOutLayers()]
        else:
            # Get the names of the output layers, i.e. the layers with unconnected outputs
            return [layersNames[i-1] for i in net.getUnconnectedOutLayers()]

    # Remove the bounding boxes with  low confidence using non-maxima suppression
    def _postprocess(self, frame, outs):
        frameHeight = frame.shape[0]
        frameWidth = frame.shape[1]

        classIds = []
        confidences = []
        boxes = []
        # Scan through all the bounding boxes output from the network and keep only the
        # ones with high confidence scores. Assign the box's class label as the class with the highest score.
        classIds = []
        confidences = []
        boxes = []
        for out in outs:
            for detection in out:
                scores = detection[5:]
                classId = np.argmax(scores)
                confidence = scores[classId]
                if confidence > self.confThreshold:
                    center_x = int(detection[0] * frameWidth)
                    center_y = int(detection[1] * frameHeight)
                    width = int(detection[2] * frameWidth)
                    height = int(detection[3] * frameHeight)
                    left = int(center_x - width / 2)
                    top = int(center_y - height / 2)
                    classIds.append(classId)
                    confidences.append(float(confidence))
                    boxes.append([left, top, width, height])

        # Perform non maximum suppression to eliminate redundant overlapping boxes with
        # lower confidences.
        indices = cv2.dnn.NMSBoxes(boxes, confidences, self.confThreshold, self.nmsThreshold)
        #list_labels = []
        #list_index = []
        detected = []


        for i in indices:
            index = i
            try:
                index = i[0]
            except:
                index = i
                pass
            box = boxes[index]
            left = box[0]
            top = box[1]
            width = box[2]
            height = box[3]

            if confidences[index] > 0.5:
                label = self.classes[classIds[index]]
                position = [left + width/2, top + height/2]
                #list_index.append(classIds[i])
                #list_labels.append(label)
                detected.append({"label":label,"center":{"x":int(position[0]), "y":int(position[1])}, "box":{"x":left, "y":top, "w":width, "h":height}, "confidence":confidences[index]})
        return detected

    def drawObjects(self, img_src):

        new_image = img_src.copy()

        for value in self.detected: 
            startX = value["box"]["x"] 
            startY = value["box"]["y"] 
            endX = startX + value["box"]["w"] 
            endY = startY + value["box"]["h"]
            cv2.rectangle(new_image, (startX, startY), (endX, endY),(255, 0, 0), 2)
            labelPosition = endY - 5
            cv2.putText(new_image, value["label"], (startX, labelPosition),
                    cv2.FONT_HERSHEY_DUPLEX, 0.4, (255, 255, 255), 1)

        # Put efficiency information. The function getPerfProfile returns the 
        # overall time for inference(t) and the timings for each of the layers(in layersTimes)
        t, _ = self.net.getPerfProfile()
        label = 'Inference time: %.2f ms' % (t * 1000.0 / cv2.getTickFrequency())
        cv2.putText(new_image, label, (0, 15), cv2.FONT_HERSHEY_SIMPLEX, 0.5, (0, 0, 255))
        return new_image
    
    def getObjects(self, img):

        blob = cv2.dnn.blobFromImage(img, 1/255, (self.config["inpWidth"], self.config["inpHeight"]), [0,0,0], 1, crop=False)
        
        # Sets the input to the network
        self.net.setInput(blob)
        
        # Runs the forward pass to get output of the output layers
        outs = self.net.forward(self._getOutputsNames(self.net))
     
        # Remove the bounding boxes with low confidence
        self.detected = self._postprocess(img, outs)

        return self.detected




import cv2
import numpy as np

def points2vector(tail, head):
    return (np.array(head) - np.array(tail))

def getAngle(vector1, vector2):
    inner_product = np.inner(vector1, vector2)
    norm_v1 = np.linalg.norm(vector1)
    norm_v2 = np.linalg.norm(vector2)

    if norm_v1 == 0.0 or norm_v2 == 0.0:
        return np.nan
    cos = inner_product / (norm_v1*norm_v2)
    # result in radians
    rad = np.arccos(np.clip(cos, -1.0, 1.0))
    # covert to degrees
    theta = np.rad2deg(rad)


class MediapipeHand():

    def __init__(self, max_num_hands=2,min_detection_confidence=0.7, min_tracking_confidence=0.7):
        import mediapipe as mp
        self.mp_hands = mp.solutions.hands


        self.landmark_line_ids = [ 
            (0, 1), (1, 5), (5, 9), (9, 13), (13, 17), (17, 0),  
            (1, 2), (2, 3), (3, 4),        
            (5, 6), (6, 7), (7, 8),        
            (9, 10), (10, 11), (11, 12),   
            (13, 14), (14, 15), (15, 16),  
            (17, 18), (18, 19), (19, 20),   
        ]

        self.mp_hands = mp.solutions.hands
        self.hands = self.mp_hands.Hands(max_num_hands=max_num_hands,min_detection_confidence=min_detection_confidence, min_tracking_confidence=min_tracking_confidence)

        self.HAND_KEYPOINTS = ["WRIST",
          "THUMB_CMC",
          "THUMB_MCP" ,
          "THUMB_IP",
          "THUMB_TIP",
          "INDEX_FINGER_MCP",
          "INDEX_FINGER_PIP",
          "INDEX_FINGER_DIP",
          "INDEX_FINGER_TIP",
          "MIDDLE_FINGER_MCP",
          "MIDDLE_FINGER_PIP",
          "MIDDLE_FINGER_DIP",
          "MIDDLE_FINGER_TIP",
          "RING_FINGER_MCP",
          "RING_FINGER_PIP",
          "RING_FINGER_DIP",
          "RING_FINGER_TIP",
          "PINKY_MCP",
          "PINKY_PIP",
          "PINKY_DIP",
          "PINKY_TIP"]

        self.dict_points = {"WRIST":{},"THUMB_CMC":{},"THUMB_MCP":{},
          "THUMB_IP":{},"THUMB_TIP":{},
          "INDEX_FINGER_MCP":{},"INDEX_FINGER_PIP":{},
          "INDEX_FINGER_DIP":{},"INDEX_FINGER_TIP":{},
          "MIDDLE_FINGER_MCP":{},"MIDDLE_FINGER_PIP":{},
          "MIDDLE_FINGER_DIP":{},"MIDDLE_FINGER_TIP":{},
          "RING_FINGER_MCP":{},"RING_FINGER_PIP":{},
          "RING_FINGER_DIP":{},"RING_FINGER_TIP":{},
          "PINKY_MCP":{},"PINKY_PIP":{},
          "PINKY_DIP":{},"PINKY_TIP":{}}


        self.HAND_VECTORS = {"TWC":["WRIST", "THUMB_CMC"],
                "TCM":["THUMB_CMC", "THUMB_MCP"],
                "TMI":["THUMB_MCP", "THUMB_IP"],
                "TIT":["THUMB_IP", "THUMB_TIP"],
                "IWM":["WRIST", "INDEX_FINGER_MCP"],
                "IMP":["INDEX_FINGER_MCP", "INDEX_FINGER_PIP"],
                "IPD":["INDEX_FINGER_PIP", "INDEX_FINGER_DIP"],
                "IDT":["INDEX_FINGER_DIP", "INDEX_FINGER_TIP"],
                "MWM":["WRIST", "MIDDLE_FINGER_MCP"],
                "MMP":["MIDDLE_FINGER_MCP", "MIDDLE_FINGER_PIP"],
                "MPD":["MIDDLE_FINGER_PIP", "MIDDLE_FINGER_DIP"],
                "MDT":["MIDDLE_FINGER_DIP", "MIDDLE_FINGER_TIP"],
                "RWM":["WRIST", "RING_FINGER_MCP"],
                "RMP":["RING_FINGER_MCP", "RING_FINGER_PIP"],
                "RPD":["RING_FINGER_PIP", "RING_FINGER_DIP"],
                "RDT":["RING_FINGER_DIP", "RING_FINGER_TIP"],
                "PWM":["WRIST", "PINKY_MCP"],
                "PMP":["PINKY_MCP", "PINKY_PIP"],
                "PPD":["PINKY_PIP", "PINKY_DIP"],
                "PDT":["PINKY_DIP", "PINKY_TIP"]
        }

        self.HAND_JOINTS2 = {"WRIST_THUMB_INDEX":["TWC","IWM"],
                "INDEX_MIDDLE":["IMP","MMP"],
                "WRIST_MIDDLE":["MWM","MMP"]
        }

        self.HAND_JOINTS = {"WRIST_THUMB_INDEX":["TWC","IWM"],
                "WRIST_INDEX":["IWM","IMP"],
                "INDEX_1":["IMP","IPD"],
                "INDEX_2":["IPD","IDT"],
                "WRIST_MIDDLE":["MWM","MMP"],
                "MIDDLE_1":["MMP","MPD"],
                "MIDDLE_2":["MPD","MDT"]
        }

        self.dict_joints = {"WRIST_THUMB_INDEX":np.zeros((1,3,)),
                "WRIST_THUMB":np.zeros((1,3,)),
                "THUMB_1":np.zeros((1,3,)),
                "THUMB_2":np.zeros((1,3,)),
                "WRIST_INDEX":np.zeros((1,3,)),
                "INDEX_1":np.zeros((1,3,)),
                "INDEX_2":np.zeros((1,3,)),
                "INDEX_MIDDLE":np.zeros((1,3,)),
                "WRIST_MIDDLE":np.zeros((1,3,)),
                "MIDDLE_1":np.zeros((1,3,)),
                "MIDDLE_2":np.zeros((1,3,))
        }




    def getAnglesFromVectors(self):

        Left = self.hand_vectors["Left"]
        Right = self.hand_vectors["Right"]
        score_l = self.data["scores"]["Left"]
        score_r = self.data["scores"]["Right"]

        for vector_name, value in self.HAND_JOINTS.items():
            if (score_l>.2):
                vector1 = self.hand_vectors["Left"][value[0]]
                vector2 = self.hand_vectors["Left"][value[1]]
                getAngle(vector1,vector2)
            
            if (score_r>.2):

                vector1 = self.hand_vectors["Right"][value[0]]
                vector2 = self.hand_vectors["Right"][value[1]]
                getAngle(vector1,vector2)

        return 0

    def getHandVectors(self):

        Left = self.data["data"]["Left"]
        Right = self.data["data"]["Right"]
        score_l = self.data["scores"]["Left"]
        score_r = self.data["scores"]["Right"]

        self.hand_vectors = {"Left":self.dict_joints.copy(), "Right":self.dict_joints.copy()} 

        for vector_name, points in self.HAND_VECTORS.items():
            if (score_l>.2):
                self.hand_vectors["Left"][vector_name] = points2vector(tail = Left[points[0]], head = Left[points[1]])
            if (score_r>.2):
                self.hand_vectors["Right"][vector_name] = points2vector(tail = Right[points[0]], head = Right[points[1]])

        return self.hand_vectors







    def getHands(self,img, draw_image = True):

        """ Get landmarks from hands 
        
        Parameters
        ----------

        img : cv2 image 
            OpenCV image

        draw_image : bool
            If true, draw landmarks in the image

        Returns
        ----------

        data : dict
            Hand data

        img : cv2 image
            Image with hands


        """

        img_h, img_w, _ = img.shape    
        img = cv2.flip(img, 1)

        self.data = {"data":{"Right": self.dict_points.copy(),"Left": self.dict_points.copy()}, "scores":{"Right":0,"Left":0}}
        results = self.hands.process(cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
        if results.multi_hand_landmarks:
            for h_id, hand_landmarks in enumerate(results.multi_hand_landmarks):

                if draw_image:
                    # plot lines
                    for line_id in self.landmark_line_ids:
                        lm = hand_landmarks.landmark[line_id[0]]
                        lm_pos1 = (int(lm.x * img_w), int(lm.y * img_h))
                        lm = hand_landmarks.landmark[line_id[1]]
                        lm_pos2 = (int(lm.x * img_w), int(lm.y * img_h))
                        cv2.line(img, lm_pos1, lm_pos2, (128, 0, 0), 1)

                    # plot circles
                    z_list = [lm.z for lm in hand_landmarks.landmark]
                    z_min = min(z_list)
                    z_max = max(z_list)
                    for lm in hand_landmarks.landmark:
                        lm_pos = (int(lm.x * img_w), int(lm.y * img_h))
                        lm_z = int((lm.z - z_min) / (z_max - z_min) * 255)
                        cv2.circle(img, lm_pos, 3, (255, lm_z, lm_z), -1)

                    hand_texts = []
                    for c_id, hand_class in enumerate(results.multi_handedness[h_id].classification):
                        #hand_texts.append("#%d-%d" % (h_id, c_id)) 
                        hand_texts.append("- Index: %d" % (hand_class.index))
                        hand_texts.append("- Label: %s" % (hand_class.label))
                        #hand_texts.append("- Score:%3.2f" % (hand_class.score * 100))
                    lm = hand_landmarks.landmark[0]
                    lm_x = int(lm.x * img_w) - 50
                    lm_y = int(lm.y * img_h) - 10
                    lm_c = (104, 0, 0)
                    font = cv2.FONT_HERSHEY_SIMPLEX
                    for cnt, text in enumerate(hand_texts):
                        cv2.putText(img, text, (lm_x, lm_y + 12 * cnt), font, 0.4, lm_c, 2)

                for c_id, hand_class in enumerate(results.multi_handedness[h_id].classification):
                    index = hand_class.index
                    label = hand_class.label
                    score = hand_class.score

                    self.data["scores"][label] = score
                    
                    j = 0
                    for lm in hand_landmarks.landmark:
                        #print(self.HAND_JOINTS)
                        self.data["data"][label][self.HAND_KEYPOINTS[j]] = [lm.x*img_w,lm.y*img_h, lm.z]
                        j = j + 1
                        
        return self.data, img

"""
h = HandDetector();

cap = cv2.VideoCapture(0)  
if cap.isOpened():
    while True:
        success, img = cap.read()
        if not success:
            continue
        data, img = h.getHands(img);
        vectors = h.getHandVectors();

        print(vectors)

        cv2.imshow("Result", img)
        key = cv2.waitKey(1) & 0xFF
        if key == ord('q') or key == ord('Q') or key == 0x1b:
            break

cap.release()
"""


from setuptools import setup

setup(

    name = 'hxri', 
    version='0.0.0.2',
    description = 'Enrique Coronado',
    packages=["hxri"],
    package_dir = {'':'src'},
    author='Enrique Coronado',
    author_email='enriquecoronadozu@gmail.com',
    url='http://enriquecoronadozu.github.io',
    include_package_data=True,
    long_description = open('README.md').read(),
    long_description_content_type = "text/markdown",
    classifiers  = [
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        "License :: OSI Approved :: BSD License",
        'Intended Audience :: Developers',
        'Intended Audience :: Other Audience',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Topic :: Text Processing',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: OS Independent',
    ],
    install_requires=[
          'nep'
    ],
    
    keywords = ['Technology'],
    
)
